@@ -334,118 +334,6 @@ void point_map(point_t R, fieldmap map, point_t P)
     R->inf_flag = 0;
 }
 
-void cc_param_init(cc_param_ptr param)
-{
-    mpz_init(param->q);
-    mpz_init(param->n);
-    mpz_init(param->h);
-    mpz_init(param->r);
-    mpz_init(param->a);
-    mpz_init(param->b);
-    mpz_init(param->nk);
-    mpz_init(param->hk);
-}
-
-void cc_param_clear(cc_param_ptr param)
-{
-    mpz_clear(param->q);
-    mpz_clear(param->n);
-    mpz_clear(param->h);
-    mpz_clear(param->r);
-    mpz_clear(param->a);
-    mpz_clear(param->b);
-    mpz_clear(param->nk);
-    mpz_clear(param->hk);
-}
-
-void cc_param_set(cc_param_ptr x, cc_param_ptr y)
-{
-    mpz_set(x->q, y->q);
-    mpz_set(x->n, y->n);
-    mpz_set(x->h, y->h);
-    mpz_set(x->r, y->r);
-    mpz_set(x->a, y->a);
-    mpz_set(x->b, y->b);
-    mpz_set(x->nk, y->nk);
-    mpz_set(x->hk, y->hk);
-}
-
-void cc_param_out_str(FILE *stream, cc_param_ptr p)
-{
-    void out(char *s, mpz_t z)
-    {
-	fprintf(stream, "%s ", s);
-	mpz_out_str(stream, 0, z);
-	fprintf(stream, "\n");
-    }
-
-    out("q", p->q);
-    out("n", p->n);
-    out("h", p->h);
-    out("r", p->r);
-    out("a", p->a);
-    out("b", p->b);
-    fprintf(stream, "k %d\n", p->k);
-    out("nk", p->nk);
-    out("hk", p->hk);
-}
-
-void cc_param_inp_str(cc_param_ptr p, FILE *stream)
-{
-    token_t tok;
-    mpz_t k;
-    mpz_ptr z;
-
-    token_init(tok);
-    mpz_init(k);
-    for (;;) {
-	token_get(tok, stream);
-	if (tok->type != token_word) {
-	    break;
-	}
-	z = NULL;
-	if (strlen(tok->s) == 1) {
-	    switch(tok->s[0]) {
-		case 'q':
-		    z = p->q;
-		    break;
-		case 'n':
-		    z = p->n;
-		    break;
-		case 'r':
-		    z = p->r;
-		    break;
-		case 'h':
-		    z = p->h;
-		    break;
-		case 'k':
-		    z = k;
-		    break;
-		case 'a':
-		    z = p->a;
-		    break;
-		case 'b':
-		    z = p->b;
-		    break;
-	    }
-	} else if (!strcmp(tok->s, "nk")) {
-	    z = p->nk;
-	} else if (!strcmp(tok->s, "hk")) {
-	    z = p->hk;
-	}
-	token_get(tok, stream);
-	if (tok->type != token_word) {
-	    break;
-	}
-	if (z) {
-	    mpz_set_str(z, tok->s, 0);
-	}
-    }
-    p->k = mpz_get_ui(k);
-    mpz_clear(k);
-    token_clear(tok);
-}
-
 static void curve_group_init(element_ptr e)
 {
     e->data = malloc(sizeof(point_t));
@@ -557,4 +445,3 @@ void field_init_curve_group(field_t f, curve_t c, mpz_t cofac)
     f->to_bytes = curve_group_to_bytes;
     f->from_bytes = curve_group_from_bytes;
 }
-
