@@ -332,7 +332,7 @@ static void poly_out_str(FILE *stream, int base, element_ptr e)
     fputc('[', stream);
     for (i=0; i<n; i++) {
 	if (i) fputc(' ', stream);
-	element_out_str(stream, 0, poly_coeff(e, i));
+	element_out_str(stream, base, poly_coeff(e, i));
     }
     fputc(']', stream);
 }
@@ -491,9 +491,9 @@ void field_init_poly(field_ptr f, field_ptr base_field)
 static void field_clear_polymod(field_ptr f)
 {
     polymod_field_data_ptr p = f->data;
-    void clear(void *p) {
-	element_clear(p);
-	free(p);
+    void clear(void *data) {
+	element_clear(data);
+	free(data);
     }
 
     darray_forall(p->xpwr, clear);
