@@ -68,4 +68,10 @@ void poly_random_monic(element_ptr f, int deg);
 void poly_make_monic(element_t f, element_t g);
 void element_field_to_poly(element_t poly, element_t constant);
 
+/* this is needed in mnt.c */
+void poly_unmod(element_ptr f);
+    //input: f in K[x]_{p(x)}
+    //output: f is now a polynomial over K[x]
+    //(i.e. the field is not modulo anything)
+
 #endif //POLY_H
